@@ -5,7 +5,7 @@
 //
 
 #include "bitmeter.h"
-#include "xosview.h"
+
 
 BitMeter::BitMeter( XOSView *parent,
 		    const char *title, const char *legend, int numBits,
@@ -48,7 +48,7 @@ void BitMeter::checkevent( void ){
   drawBits();
 }
 
-void BitMeter::drawBits( int manditory ){
+void BitMeter::drawBits( int mandatory ){
   static int pass = 1;
 
 //  pass = (pass + 1) % 2;
@@ -61,7 +61,7 @@ void BitMeter::drawBits( int manditory ){
     else
       x2 = x_ + (width_+1) - 1;
 
-    if ( (bits_[i] != lastbits_[i]) || manditory ){
+    if ( (bits_[i] != lastbits_[i]) || mandatory ){
       if ( bits_[i] && pass )
 	parent_->setForeground( onColor_ );
       else
@@ -88,9 +88,9 @@ void BitMeter::draw( void ){
 
     int offset;
     if ( dousedlegends_ )
-      offset = parent_->textWidth( "XXXXXXXXX" );
+      offset = parent_->textWidth( "XXXXXXXXXX" );
     else
-      offset = parent_->textWidth( "XXXXX" );
+      offset = parent_->textWidth( "XXXXXX" );
 
     parent_->drawString( x_ - offset + 1, y_ + height_, title_ );
     parent_->setForeground( onColor_ );
