@@ -8,8 +8,8 @@
 #define _BITMETER_H_
 
 #include "meter.h"
+#include "xosview.h"
 
-class XOSView;
 
 class BitMeter : public Meter {
 public:
@@ -34,7 +34,7 @@ protected:
 
   void setBits(int startbit, unsigned char values);
 
-  void drawBits( int manditory = 0 );
+  void drawBits( int mandatory = 0 );
 private:
 };
 
