@@ -11,27 +11,29 @@
 //    authors for a copy.
 //
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
+#include "MeterMaker.h"
 #include "defines.h"
 #include "kernel.h"
-#include "MeterMaker.h"
-#include "xosview.h"
-#include "btrymeter.h"
+#include "loadmeter.h"
 #include "cpumeter.h"
 #include "memmeter.h"
 #include "swapmeter.h"
-#include "netmeter.h"
-#include "loadmeter.h"
-#include "diskmeter.h"
 #include "pagemeter.h"
+#include "netmeter.h"
+#include "diskmeter.h"
 #include "intmeter.h"
 #include "intratemeter.h"
+#include "btrymeter.h"
+#if defined(__i386__) || defined(__x86_64__)
 #include "coretemp.h"
+#endif
 #include "sensor.h"
-//  This one is not yet supported under *BSD.
-//#include "serialmeter.h"
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <iostream>
+
 
 MeterMaker::MeterMaker(XOSView *xos) {
 	_xos = xos;
@@ -42,8 +44,29 @@ void MeterMaker::makeMeters(void) {
 	if ( _xos->isResourceTrue("load") )
 		push(new LoadMeter(_xos));
 
-	if ( _xos->isResourceTrue("cpu") )
-		push(new CPUMeter(_xos));
+	if ( _xos->isResourceTrue("cpu") ) {
+		bool single, both, all;
+		unsigned int cpuCount = BSDCountCpus();
+
+		single = ( strncmp(_xos->getResource("cpuFormat"), "single", 2) == 0 );
+		both = ( strncmp(_xos->getResource("cpuFormat"), "both", 2) == 0 );
+		all = ( strncmp(_xos->getResource("cpuFormat"), "all", 2) == 0 );
+
+		if ( strncmp(_xos->getResource("cpuFormat"), "auto", 2) == 0 ) {
+			if (cpuCount == 1 || cpuCount > 4)
+				single = true;
+			else
+				all = true;
+		}
+
+		if (single || both)
+			push(new CPUMeter(_xos, 0));
+
+		if (all || both) {
+			for (unsigned int i = 1; i <= cpuCount; i++)
+				push(new CPUMeter(_xos, i));
+		}
+	}
 
 	if ( _xos->isResourceTrue("mem") )
 		push(new MemMeter(_xos));
@@ -69,14 +92,15 @@ void MeterMaker::makeMeters(void) {
 	if ( _xos->isResourceTrue("battery") && BSDHasBattery() )
 		push(new BtryMeter(_xos));
 
-	if ( _xos->isResourceTrue("coretemp") ) {
-		char caption[25];
-		snprintf(caption, 25, "TEMPERATURE (C)/%s",
+#if defined(__i386__) || defined(__x86_64__)
+	if ( _xos->isResourceTrue("coretemp") && CoreTemp::countCpus() > 0 ) {
+		char caption[32];
+		snprintf(caption, 32, "ACT(\260C)/HIGH/%s",
 		         _xos->getResourceOrUseDefault( "coretempHighest", "100" ) );
 		const char *displayType = _xos->getResourceOrUseDefault("coretempDisplayType", "separate");
 		if (strncmp(displayType, "separate", 1) == 0) {
 			char name[5];
-			for (int i = 0; i < BSDCountCpus(); i++) {
+			for (uint i = 0; i < CoreTemp::countCpus(); i++) {
 				snprintf(name, 5, "CPU%d", i);
 				push(new CoreTemp(_xos, name, caption, i));
 			}
@@ -90,32 +114,26 @@ void MeterMaker::makeMeters(void) {
 			_xos->done(1);
 		}
 	}
-
-	if ( _xos->isResourceTrue("bsdsensor") ) {
-		char caption[25], label[5];
-		for (int i = 1 ; ; i++) {
-			char s[20];
-			snprintf(s, 20, "bsdsensorHigh%d", i);
-			const char *high = _xos->getResourceOrUseDefault(s, "100");
-			snprintf(caption, 25, "ACT/HIGH/%s", high);
-			snprintf(s, 20, "bsdsensor%d", i);
-			const char *res = _xos->getResourceOrUseDefault(s, NULL);
-			if (!res || !*res)
-				break;
-			snprintf(s, 20, "bsdsensorLabel%d", i);
-			snprintf(label, 5, "SEN%d", i);
-			const char *lab = _xos->getResourceOrUseDefault(s, label);
-			push(new BSDSensor(_xos, res, high, lab, caption, i));
-		}
-	}
-
-
-#ifdef HAVE_BATTERY_METER
-	//  NOTE:  None of the recent *BSDs supports the Battery Meter any longer.
-	//  This one is done in its own file, not kernel.cc
-	if ( _xos->isResourceTrue("battery") )
-		push(new BtryMeter(_xos));
 #endif
 
-	//  The serial meters are not yet available for the BSDs.  BCG
+	if ( _xos->isResourceTrue("bsdsensor") ) {
+		char caption[16], l[8], s[16];
+		for (int i = 1 ; ; i++) {
+			snprintf(s, 16, "bsdsensorHighest%d", i);
+			float highest = atof( _xos->getResourceOrUseDefault(s, "100") );
+			snprintf(caption, 16, "ACT/HIGH/%f", highest);
+			snprintf(s, 16, "bsdsensor%d", i);
+			const char *name = _xos->getResourceOrUseDefault(s, NULL);
+			if (!name || !*name)
+				break;
+			snprintf(s, 16, "bsdsensorHigh%d", i);
+			const char *high = _xos->getResourceOrUseDefault(s, NULL);
+			snprintf(s, 16, "bsdsensorLow%d", i);
+			const char *low = _xos->getResourceOrUseDefault(s, NULL);
+			snprintf(s, 16, "bsdsensorLabel%d", i);
+			snprintf(l, 8, "SEN%d", i);
+			const char *label = _xos->getResourceOrUseDefault(s, l);
+			push(new BSDSensor(_xos, name, high, low, label, caption, i));
+		}
+	}
 }
