@@ -15,6 +15,7 @@
 #define _DISKMETER_H_
 
 #include "fieldmetergraph.h"
+#include "xosview.h"
 #include "defines.h"
 
 
@@ -32,7 +33,7 @@ protected:
 
 private:
 #ifndef HAVE_DEVSTAT
-	u_int64_t prevreads_, prevwrites_;
+	uint64_t prevreads_, prevwrites_;
 #endif
 	double maxBandwidth_;
 };
