@@ -8,6 +8,7 @@
 #define _INTMETER_H_
 
 #include "bitmeter.h"
+#include "xosview.h"
 #include <map>
 
 
@@ -22,7 +23,7 @@ public:
 	void checkResources( void );
 
 private:
-	unsigned long *irqs_, *lastirqs_;
+	uint64_t *irqs_, *lastirqs_;
 	unsigned int *inbrs_;
 	unsigned int irqcount_;
 	std::map<int,int> realintnum_;
