@@ -12,6 +12,7 @@
 #define _IRQRATEMETER_H_
 
 #include "fieldmetergraph.h"
+#include "xosview.h"
 
 
 class IrqRateMeter : public FieldMeterGraph {
@@ -24,7 +25,7 @@ public:
 	void checkResources( void );
 
 private:
-	unsigned long *irqs_, *lastirqs_;
+	uint64_t *irqs_, *lastirqs_;
 	unsigned int irqcount_;
 
 protected:
