@@ -219,8 +219,10 @@ OpenKDIfNeeded() {
 	 *  that kernel file.  Otherwise, use the default kernel, by
 	 *  specifying NULL.  */
 	if ((kd = kvm_openfiles((kernelFileName[0] ? kernelFileName : NULL),
-		                    NULL, NULL, O_RDONLY, errstring)) == NULL)
-		err(EX_OSFILE, "OpenKDIfNeeded(): %s", errstring);
+		                    NULL, NULL, O_RDONLY, errstring)) == NULL) {
+		warn("OpenKDIfNeeded(): %s", errstring);
+		return;
+	}
 
 	// Parenthetical note:  FreeBSD kvm_openfiles() uses getbootfile() to get
 	// the correct kernel file if the 1st arg is NULL.  As far as I can see,
@@ -276,7 +278,7 @@ BSDGetCPUSpeed() {
 	size = sizeof(speed);
 #if defined(XOSVIEW_NETBSD)
 	if ( sysctlbyname("machdep.tsc_freq", &speed, &size, NULL, 0) < 0 )
-		err(EX_OSERR, "sysctl machdep.tsc_freq failed");
+		warn("sysctl machdep.tsc_freq failed");
 #else  /* XOSVIEW_DFBSD */
 	if ( sysctlbyname("hw.tsc_frequency", &speed, &size, NULL, 0) < 0 )
 		err(EX_OSERR, "sysctl hw.tsc_frequency failed");
