@@ -326,8 +326,9 @@ const char *CPUMeter::cpuStr(int num){
 }
 
 const char *CPUMeter::toUpper(const char *str){
-  static char buffer[MAX_PROCSTAT_LENGTH];
-  strncpy(buffer, str, MAX_PROCSTAT_LENGTH);
+  static char buffer[MAX_PROCSTAT_LENGTH + 1];
+  snprintf(buffer, MAX_PROCSTAT_LENGTH + 1, "%s", str);
+  buffer[MAX_PROCSTAT_LENGTH] = 0;
   for (char *tmp = buffer ; *tmp != '\0' ; tmp++)
     *tmp = toupper(*tmp);
 
