@@ -1,32 +1,29 @@
 //
 //  Initial port performed by Greg Onufer (exodus@cheers.bungi.com)
 //
+
 #include "cpumeter.h"
-#include "xosview.h"
 #include <stdlib.h>
-#include <unistd.h>
-#include <ctype.h>
-#include <string.h>
-#include <sstream>
+#include <stdio.h>
+#include <strings.h>
+#include <sys/sysinfo.h>
+
 
 CPUMeter::CPUMeter(XOSView *parent, kstat_ctl_t *_kc, int cpuid)
-	: FieldMeterGraph(parent, CPU_STATES, toUpper(cpuStr(cpuid)),
-	    "USER/SYS/WAIT/IDLE")
+	: FieldMeterGraph(parent, CPU_STATES, cpuStr(cpuid), "USER/SYS/WAIT/IDLE")
 {
 	kc = _kc;
+	aggregate = ( cpuid < 0 );
 	for (int i = 0 ; i < 2 ; i++)
 		for (int j = 0 ; j < CPU_STATES ; j++)
 			cputime_[i][j] = 0;
 	cpuindex_ = 0;
+	cpustats = KStatList::getList(kc, KStatList::CPU_STAT);
 
-	int j = 0;
-	for (ksp = kc->kc_chain; ksp != NULL; ksp = ksp->ks_next) {
-		if (strncmp(ksp->ks_name, "cpu_stat", 8) == 0) {
-			j++;
-			if (j == cpuid)
-				break;
-		}
-	}
+	if (!aggregate)
+		for (unsigned int i = 0; i < cpustats->count(); i++)
+			if ((*cpustats)[i]->ks_instance == cpuid)
+				ksp = (*cpustats)[i];
 }
 
 CPUMeter::~CPUMeter(void)
@@ -58,14 +55,30 @@ void CPUMeter::getcputime(void)
 	total_ = 0;
 	cpu_stat_t cs;
 
-	if (kstat_read(kc, ksp, &cs) == -1) {
-		parent_->done(1);
-		return;
+	if (aggregate) {
+		cpustats->update(kc);
+		bzero(cputime_[cpuindex_], CPU_STATES * sizeof(cputime_[cpuindex_][0]));
+		for (unsigned int i = 0; i < cpustats->count(); i++) {
+			if (kstat_read(kc, (*cpustats)[i], &cs) == -1) {
+				parent_->done(1);
+				return;
+			}
+			cputime_[cpuindex_][0] += cs.cpu_sysinfo.cpu[CPU_USER];
+			cputime_[cpuindex_][1] += cs.cpu_sysinfo.cpu[CPU_KERNEL];
+			cputime_[cpuindex_][2] += cs.cpu_sysinfo.cpu[CPU_WAIT];
+			cputime_[cpuindex_][3] += cs.cpu_sysinfo.cpu[CPU_IDLE];
+		}
+	}
+	else {
+		if (kstat_read(kc, ksp, &cs) == -1) {
+			parent_->done(1);
+			return;
+		}
+		cputime_[cpuindex_][0] = cs.cpu_sysinfo.cpu[CPU_USER];
+		cputime_[cpuindex_][1] = cs.cpu_sysinfo.cpu[CPU_KERNEL];
+		cputime_[cpuindex_][2] = cs.cpu_sysinfo.cpu[CPU_WAIT];
+		cputime_[cpuindex_][3] = cs.cpu_sysinfo.cpu[CPU_IDLE];
 	}
-	cputime_[cpuindex_][0] = cs.cpu_sysinfo.cpu[CPU_USER];
-	cputime_[cpuindex_][1] = cs.cpu_sysinfo.cpu[CPU_KERNEL];
-	cputime_[cpuindex_][2] = cs.cpu_sysinfo.cpu[CPU_WAIT];
-	cputime_[cpuindex_][3] = cs.cpu_sysinfo.cpu[CPU_IDLE];
 
 	int oldindex = (cpuindex_ + 1) % 2;
 	for (int i = 0 ; i < CPU_STATES ; i++) {
@@ -78,40 +91,11 @@ void CPUMeter::getcputime(void)
 		setUsed(total_ - fields_[3], total_);
 }
 
-const char *CPUMeter::toUpper(const char *str)
+const char *CPUMeter::cpuStr(int num)
 {
-	static char buffer[256];
-	strncpy(buffer, str, 256);
-	for (char *tmp = buffer ; *tmp != '\0' ; tmp++)
-		*tmp = toupper(*tmp);
-
+	static char buffer[8] = "CPU";
+	if (num >= 0)
+		snprintf(buffer + 3, 4, "%d", num);
+	buffer[7] = '\0';
 	return buffer;
 }
-
-const char *CPUMeter::cpuStr(int num)
-    {
-    static char buffer[32];
-    std::ostringstream str;
-
-    str << "cpu";
-    if (num != 0)
-        str << (num - 1);
-    str << std::ends;
-
-    strncpy(buffer, str.str().c_str(), 32);
-    buffer[31] = '\0';
-
-    return buffer;
-    }
-
-int CPUMeter::countCPUs(kstat_ctl_t *kc)
-{
-	kstat_t *ksp;
-	int i = 0;
-
-        for (ksp = kc->kc_chain; ksp != NULL; ksp = ksp->ks_next) {
-                if (strncmp(ksp->ks_name, "cpu_stat", 8) == 0)
-                        i++;
-        }
-	return (i);
-}
